# Centrify Delegated Machine Credential for Python Library

Delegated Machine Credentials is the capability to trust a Windows or Linux computer to make specific API calls to privileged access service. Included in the definition are "machine scopes".  A machine scope may contain a range of PAS API endpoints that may be called by the trusted computer using the Centrify Command Line Interface. Some examples include trusting the computer to retrieve the contents of a secret, creating/reading/updating PAS objects (such as systems/accounts ETC) or reading other metadata from the PAS platform. Machine scopes may be configured at the time the computer is enrolled using cenroll or via the privileged access service platform interface (Resources → Systems → Computer → Client Profile)